#!/usr/bin/perl -w
#
# Copyright (c) 2007 VMware, Inc.  All rights reserved.

use strict;
use warnings;

use FindBin;
use lib "$FindBin::Bin/../";

use VMware::VIRuntime;
use VMware::VIExt;
use XML::LibXML;
use AppUtil::VMUtil;
use AppUtil::XMLInputUtil;

sub do_browse;
sub get_logfile;
sub do_put;

$Util::script_version = "1.0";

my %opts = (
   'vmname' => {
      type => "=s",
      help => "Name of the datacenter",
      required => 1,
   },
   'localpath' => {
      type => "=s",
      help => "localpath",
      required => 1,
   },
);

sub extract_log;

Opts::add_options(%opts);
Opts::parse();
Opts::validate();

Util::connect();
extract_log();
Util::disconnect();

sub extract_log() {
   my $vmname = Opts::get_option('vmname');
   my $vm = Vim::find_entity_view(view_type => 'VirtualMachine',
                                  filter => { 'name' => $vmname});
   if(defined $vm) {
      my $logdirectory = $vm->config->files->logDirectory;
      my $remotepath = get_remote_path($logdirectory);
      my $dsname = get_datastore_name($logdirectory);
      my $dcname = get_datacenter_name($vm);
      $remotepath = $remotepath . "/vmware.log";
      get_log($remotepath,$dsname,$dcname);
   }
   else {
      print "\nVirtual Machine $vmname not found\n";
   }
}

sub get_log() {
   my ($remotepath,$dsname,$dcname) = @_;
   print "\nExtracting vmware.log file \n";
   my $resp = VIExt::http_get_file("folder",
                                   $remotepath,
                                   $dsname,
                                   $dcname,
                                   Opts::get_option('localpath'));
   check_response($resp);
}

sub get_remote_path() {
   my ($localpath) = @_;
   my $ind = index($localpath, "]");
   my $remotepath = substr($localpath,$ind+1);
   return $remotepath;
}

sub get_datastore_name() {
   my ($localpath) = @_;
   my $ind = index($localpath, "]");
   my $dsname = substr($localpath,1,$ind-1);
   return $dsname;
}

sub get_datacenter_name() {
   my ($vmmor) = @_;
   my $parent = $vmmor->parent;
   my $parent_view = Vim::get_view(mo_ref => $parent);
   $parent = $parent_view->parent;
   $parent_view = Vim::get_view(mo_ref => $parent);
   return $parent_view->name;
}

sub check_response {
   my ($resp) = @_;
   if ($resp) {
      if (!$resp->is_success) {
         my $ind = index($resp->status_line,'404 Not Found');
         if($ind != -1) {
           print "\nService Not Available\n";
         }
      }
      else {
         print "\nGet operation completed successfully\n";
      }
   }
   else {
      print STDERR "\nGET unsuccessful : failed to get response\n";
   }
}

=head1 NAME

extractlog.pl - Allows to extract the vmware.log for any virtual machine.

=head1 SYNOPSIS

extractlog.pl [options]

=head1 DESCRIPTION

This VI Perl command-line utility provides an interface to extract the vmware.log
for any virtual machine.

=head1 OPTIONS

=head2 GENERAL OPTIONS

=over

=item B<vmname>

Name of the Virtual Machine.

=item B<localpath>

Localpath to save the extracted log.

=back

=head1 EXAMPLES

To extract the vmware.log of Virtual Machine "ABC" at location "C:/tmp":

   extrractlog.pl --url <https://<IP Address>:<Port>/sdk/vimService>
                    --username myuser --password mypassword --localpath "C:/tmp"
                    --vmname ABC

=head1 SUPPORTED PLATFORMS

All operations work with VMware VirtualCenter 2.5.

All operations work with VMware ESX Server 3.5.